select distinct owner
from all_constraints
order by owner
